import time

from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait

from common.driver import get_app_driver


class KeyWord:

    def __init__(self, driver, *args):
        self.driver = driver

    #显示等待：在5秒事件里面，每隔0.5秒调用一次until中的方法，直到返回值为True

    def wait(self, func,*args):
        return WebDriverWait(self.driver, 5).until(func)

    def find_element(self, by, value, need_wait=False,*args):
        def f(driver, *args):
            if driver.find_element(by, value).text:

                msg = driver.find_element(by, value).text
                if need_wait:  # 如果有实际结果文本信息
                    # 当元素存在，但是没有任何内容时，需要进行空值替换，直到有内容获取返回
                    return msg.replace(" ", "")
                else:
                    return True  # 直接成功（没有获取实际结果的内容直接定位元素）
            else:
                return True

        self.wait(f)  # 通过self对象，调用类方法触发显式等待
        return self.driver.find_element(by, value)  # 通过selenium本身元素定位方法进行等待完毕之后再定位

    # def click(self, loc: str, by=By.XPATH, *args):
    #     el1 = self.find_element(by, loc)
    #     # selenium原生的点击方法click()
    #     el1.click()

    def click(self, loc:str, by, *args):
        el1 = self.find_element(by,loc)
        el1.click()

    # 输入关键字封装
    def input(self, loc: str, by, content=""):
        el1 = self.find_element(by, loc)
        el1.send_keys(content)

    def gettext(self,loc: str,*args):

        el1 = self.find_element(By.ID,loc).text
        return el1

    def assert_text(self,loc:str,text:str,*args):

        el_text=self.gettext(loc)
        assert text == el_text
        print(text+"断言成功")

    # 强制等待
    def sleep(self, x,*args):
        time.sleep(x)

    def swipe(self,start_x:int,start_y:int,end_x:int,end_y:int,duration:int =0):
        self.driver.swipe(start_x,start_y,end_x,end_y)

    def tap(self, positions: list, duration:int,*args):
        self.driver.tap(positions, duration)

    def scroll(self,a,b,by,*args,duration:int =0):
        et1 = self.find_element(by,a)
        et2 = self.find_element(by,b)
        print("******************进入scroll***********************")
        self.driver.scroll(et1,et2)

    def screen_shot(self, name:str,*args):
        pic_name = './data/image/'+name+'.png'
        pic_name2 = name+'.png'
        print(pic_name)
        self.driver.get_screenshot_as_file(pic_name)
        self.driver.save_screenshot(pic_name2)
